documentationtools.ModuleCrawler
================================

.. abjad-lineage:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler

.. autoclass:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.ignored_directories
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.root_package_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__repr__
   :noindex:
